var EXPORTED_SYMBOLS = ["Prototype"];

/*  Prototype JavaScript framework, version 1.6.0.3
 *  (c) 2005-2008 Sam Stephenson
 *
 *  Prototype is freely distributable under the terms of an MIT-style license.
 *  For details, see the Prototype web site: http://www.prototypejs.org/
 *
 *--------------------------------------------------------------------------*/

var window = Components.classes["@mozilla.org/appshell/appShellService;1"]
                                .getService(Components.interfaces.nsIAppShellService)
                                .hiddenDOMWindow;

var document = window.document;

var html_doc_type = document.implementation.createDocumentType("html:html","-//W3C//DTD HTML 4.01 Transitional//EN","");
var html_doc = document.implementation.createDocument(null,null,html_doc_type);

var Prototype = {
  Version: '1.6.0.3',

  emptyFunction: function() { },
  K: function(x) { return x },

	$break: { },
	
  $A: function(iterable) {
	  if (!iterable) return [];
	  if (iterable.toArray) return iterable.toArray();
	  var length = iterable.length || 0, results = new Array(length);
	  while (length--) results[length] = iterable[length];
	  return results;
	},

	$w: function(string) {
	  if (!Prototype.O.isString(string)) return [];
	  string = Prototype.S.strip(string);
	  return string ? string.split(/\s+/) : [];
	},

	$H: function(object) {
	  return new Prototype.Hash(object);
	},
	
	$R: function(start, end, exclusive) {
	  return new Prototype.NumberRange(start, end, exclusive);
	},

	/* Classes implementation */
	/* Based on Alex Arnell's inheritance implementation. */
	Class: {
	  create: function() {
	    var parent = null, properties = Prototype.$A(arguments);
	    if (Prototype.O.isFunction(properties[0]))
	      parent = properties.shift();
	
	    function klass() {
	      this.initialize.apply(this, arguments);
	    }
	
	    Prototype.O.extend(klass, Prototype.Class.Methods);
	    klass.superclass = parent;
	    klass.subclasses = [];
	
	    if (parent) {
	      var subclass = function() { };
	      subclass.prototype = parent.prototype;
	      klass.prototype = new subclass;
	      parent.subclasses.push(klass);
	    }
	
	    for (var i = 0; i < properties.length; i++)
	      klass.addMethods(properties[i]);
	
	    if (!klass.prototype.initialize)
	      klass.prototype.initialize = Prototype.emptyFunction;
	
	    klass.prototype.constructor = klass;
	
	    return klass;
	  },

	  Methods: {
		  addMethods: function(source) {
		    var ancestor   = this.superclass && this.superclass.prototype;
		    var properties = Prototype.O.keys(source);
		
		    if (!Prototype.O.keys({ toString: true }).length)
		      properties.push("toString", "valueOf");
		
		    for (var i = 0, length = properties.length; i < length; i++) {
		      var property = properties[i], value = source[property];
		      if (ancestor && Prototype.O.isFunction(value) &&
		          Prototype.F.argumentNames(value)[0] == "$super") {
		        var method = value;
		        value = Prototype.F.wrap((function(m) {
		          return function() { return ancestor[m].apply(this, arguments) };
		        })(property),method);
		
		        value.valueOf = Prototype.F.bind(method.valueOf,method);
		        value.toString = Prototype.F.bind(method.toString,method);
		      }
		      this.prototype[property] = value;
		    }
		
		    return this;
		  }
	  }
	},
	
	Abstract: { },

	/* Object functions */
	
	O: {
		extend: function(destination, source) {
		  for (var property in source)
		    destination[property] = source[property];
		  return destination;
		},
	
		inspect: function(object) {
	    try {
	      if (Prototype.O.isUndefined(object)) return 'undefined';
	      if (object === null) return 'null';
	      if (Prototype.O.isArray(object)) return Prototype.A.inspect(object);
	      return object.inspect ? object.inspect() : String(object);
	    } catch (e) {
	      if (e instanceof RangeError) return '...';
	      throw e;
	    }
	  },
	
	  toJSON: function(object) {
	  	var jsonEnc = Components.classes["@mozilla.org/dom/json;1"]
	  	            	                   .createInstance(Components.interfaces.nsIJSON);
	  	return jsonEnc.encode(object);
	  },
	
	  toQueryString: function(object) {
	    return Prototype.$H(object).toQueryString();
	  },
	
	  keys: function(object) {
	    var keys = [];
	    for (var property in object)
	      keys.push(property);
	    return keys;
	  },
	
	  values: function(object) {
	    var values = [];
	    for (var property in object)
	      values.push(object[property]);
	    return values;
	  },
	
	  clone: function(object) {
	    return Prototype.O.extend({ }, object);
	  },
	
	  isElement: function(object) {
	    return !!(object && object.nodeType == 1);
	  },
	
	  isArray: function(object) {
	    return object != null && typeof object == "object" &&
	      'splice' in object && 'join' in object;
	  },
	
	  isHash: function(object) {
	    return object instanceof Prototype.Hash;
	  },
	
	  isFunction: function(object) {
	    return typeof object == "function";
	  },
	
	  isString: function(object) {
	    return typeof object == "string";
	  },
	
	  isNumber: function(object) {
	    return typeof object == "number";
	  },
	
	  isUndefined: function(object) {
	    return typeof object == "undefined";
	  }
	},

	/* Function functions */
	F: {
	  argumentNames: function(f) {
	    var names = f.toString().match(/^[\s\(]*function[^(]*\(([^\)]*)\)/)[1]
	      .replace(/\s+/g, '').split(',');
	    return names.length == 1 && !names[0] ? [] : names;
	  },
	
	  bind: function() {
	    if (arguments.length < 3 && Prototype.O.isUndefined(arguments[1])) return this;
	    var args = Prototype.$A(arguments), __method = args.shift(), object = args.shift();
	    return function() {
	      return __method.apply(object, args.concat(Prototype.$A(arguments)));
	    }
	  },
	
	  bindAsEventListener: function() {
	    var args = Prototype.$A(arguments), __method = args.shift(), object = args.shift();
	    return function(event) {
	      return __method.apply(object, [event].concat(args));
	    }
	  },
	
	  curry: function() {
	    if (!arguments.length) return this;
	    var args = Prototype.$A(arguments), __method = args.shift();
	    return function() {
	      return __method.apply(this, args.concat(Prototype.$A(arguments)));
	    }
	  },
	
	  delay: function() {
	    var args = Prototype.$A(arguments), __method = args.shift(), timeout = args.shift() * 1000;
	    return window.setTimeout(function() {
	      return __method.apply(__method, args);
	    }, timeout);
	  },
	
	  defer: function(f) {
	    var args = [f,0.01].concat(Prototype.$A(arguments));
	    return Prototype.F.delay.apply(f, args);
	  },
	
	  wrap: function(f,wrapper) {
	    var __method = f;
	    return function() {
	      return wrapper.apply(this, [Prototype.F.bind(__method,this)].concat(Prototype.$A(arguments)));
	    }
	  },
	
	  methodize: function(f) {
	    if (f._methodized) return f._methodized;
	    var __method = f;
	    return f._methodized = function() {
	      return __method.apply(null, [this].concat(Prototype.$A(arguments)));
	    };
	  },
	  
	  demethodize: function(f) {
	  	if (f._demethodized) return f._demethodized;
	  	var __method = f;
	  	return f._demethodized = function() {
	  		var args = Prototype.$A(arguments), context = args.shift();
	  		return __method.apply(context,args);
	  	};
	  }
	},

	/* Try function */
	Try: {
	  these: function() {
	    var returnValue;
	
	    for (var i = 0, length = arguments.length; i < length; i++) {
	      var lambda = arguments[i];
	      try {
	        returnValue = lambda();
	        break;
	      } catch (e) { }
	    }
	
	    return returnValue;
	  }
	},
	
	/* String functions */
	
	S: {

		escape: function(str) {
	 		return String(str).replace(/([.*+?^=!:${}()|[\]\/\\])/g, '\\$1');
		},

		interpret: function(value) {
	    return value == null ? '' : String(value);
	  },

	  specialChar: {
	    '\b': '\\b',
	    '\t': '\\t',
	    '\n': '\\n',
	    '\f': '\\f',
	    '\r': '\\r',
	    '\\': '\\\\'
	  },

	  gsub: function(source, pattern, replacement) {
	    var result = '', match;
	    replacement = Prototype.S._prepareReplacement(replacement);

	    while (source.length > 0) {
	      if (match = source.match(pattern)) {
	        result += source.slice(0, match.index);
	        result += Prototype.S.interpret(replacement(match));
	        source  = source.slice(match.index + match[0].length);
	      } else {
	        result += source, source = '';
	      }
	    }
	    return result;
	  },

	  sub: function(source, pattern, replacement, count) {
	    replacement = Prototype.S._prepareReplacement(replacement);
	    count = Prototype.O.isUndefined(count) ? 1 : count;

	    return Prototype.S.gsub(source,pattern, function(match) {
	      if (--count < 0) return match[0];
	      return replacement(match);
	    });
	  },

	  scan: function(source, pattern, iterator) {
	  	Prototype.S.gsub(source,pattern, iterator);
	    return String(source);
	  },

	  truncate: function(source, length, truncation) {
	    length = length || 30;
	    truncation = Prototype.O.isUndefined(truncation) ? '...' : truncation;
	    return source.length > length ?
	      source.slice(0, length - truncation.length) + truncation : String(source);
	  },

	  strip: function(source) {
	    return source.replace(/^\s+/, '').replace(/\s+$/, '');
	  },

	  stripTags: function(source) {
	    return source.replace(/<\/?[^>]+>/gi, '');
	  },

	  toQueryParams: function(source,separator) {
	    var match = Prototype.S.strip(source).match(/([^?#]*)(#.*)?$/);
	    if (!match) return { };

	    return match[1].split(separator || '&').reduce(function(hash, pair) {
	      if ((pair = pair.split('='))[0]) {
	        var key = decodeURIComponent(pair.shift());
	        var value = pair.length > 1 ? pair.join('=') : pair[0];
	        if (value != undefined) value = decodeURIComponent(value);

	        if (key in hash) {
	          if (!Prototype.O.isArray(hash[key])) hash[key] = [hash[key]];
	          hash[key].push(value);
	        }
	        else hash[key] = value;
	      }
	      return hash;
	    },{});
	  },

	  toArray: function(source) {
	    return source.split('');
	  },

	  times: function(source,count) {
	    return count < 1 ? '' : new Array(count + 1).join(source);
	  },

	  camelize: function(source) {
	    var parts = source.split('-'), len = parts.length;
	    if (len == 1) return parts[0];

	    var camelized = source.charAt(0) == '-'
	      ? parts[0].charAt(0).toUpperCase() + parts[0].substring(1)
	      : parts[0];

	    for (var i = 1; i < len; i++)
	      camelized += parts[i].charAt(0).toUpperCase() + parts[i].substring(1);

	    return camelized;
	  },

	  capitalize: function(source) {
	    return source.charAt(0).toUpperCase() + source.substring(1).toLowerCase();
	  },

	  underscore: function(source) {
	    return Prototype.S.gsub(
	    		Prototype.S.gsub(
	    				Prototype.S.gsub(
	    						Prototype.S.gsub(source,/::/, '/'),
	    						/([A-Z]+)([A-Z][a-z])/,'#{1}_#{2}'),
	    				/([a-z\d])([A-Z])/,'#{1}_#{2}'),
	    		/-/,'_').toLowerCase();
	  },

	  dasherize: function(source) {
	    return Prototype.S.gsub(source,/_/,'-');
	  },

	  inspect: function(source,useDoubleQuotes) {
	    var escapedString = Prototype.S.gsub(source,/[\x00-\x1f\\]/, function(match) {
	      var character = Prototype.S.specialChar[match[0]];
	      return character ? character : '\\u00' + Prototype.N.toPaddedString(match[0].charCodeAt(),2, 16);
	    });
	    if (useDoubleQuotes) return '"' + escapedString.replace(/"/g, '\\"') + '"';
	    return "'" + escapedString.replace(/'/g, '\\\'') + "'";
	  },

	  decodeJSON: function(source) {
	  	var jsonDec = Components.classes["@mozilla.org/dom/json;1"]
	  	                   .createInstance(Components.interfaces.nsIJSON);
	    try {
	      return jsonDec.decode(source);
	    } catch (e) { }
	    throw new SyntaxError('Badly formed JSON string: ' + Prototype.S.inspect(source));
	  },

	  include: function(source,pattern) {
	    return source.indexOf(pattern) > -1;
	  },

	  startsWith: function(source,pattern) {
	    return source.indexOf(pattern) === 0;
	  },

	  endsWith: function(source,pattern) {
	    var d = source.length - pattern.length;
	    return d >= 0 && source.lastIndexOf(pattern) === d;
	  },

	  empty: function(source) {
	    return source == '';
	  },

	  blank: function(source) {
	    return /^\s*$/.test(source);
	  },

	  interpolate: function(source,object, pattern) {
	    return new Prototype.Template(source, pattern).evaluate(object);
	  },

	  escapeHTML: function(source) {
	    return source.replace(/&/g,'&amp;').replace(/</g,'&lt;').replace(/>/g,'&gt;');
	  },
	  unescapeHTML: function(source) {
	    var div = html_doc.createElement("div");
	    div.innerHTML = Prototype.S.stripTags(source);
	    return div.childNodes[0] ? (div.childNodes.length > 1 ?
	      $A(div.childNodes).reduce(function(memo, node) { return memo+node.nodeValue },'') :
	      div.childNodes[0].nodeValue) : '';
	  },
	  
	  _prepareReplacement: function(replacement) {
		  if (Prototype.O.isFunction(replacement)) return replacement;
		  var template = new Prototype.Template(replacement);
		  return function(match) { return template.evaluate(match) };
		}
	},

	Enumerable: {

	  each: function(iterator, context) {
		  var index = 0;
			var eachF = this._each;
			if (Prototype.O.isArray(this)) {
				eachF = Prototype.A._each;
			}
		  try {
		    eachF.call(this,function(value) {
		      iterator.call(context, value, index++);
		    });
		  } catch (e) {
		    if (e != Prototype.$break) throw e;
		  }
		  return this;
		},
		
	  all: function(iterator, context) {
	    iterator = iterator || Prototype.K;
	    var result = true;
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      result = result && !!iterator.call(context, value, index);
	      if (!result) throw Prototype.$break;
	    });
	    return result;
	  },

	  any: function(iterator, context) {
	    iterator = iterator || Prototype.K;
	    var result = false;
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      if (result = !!iterator.call(context, value, index))
	        throw Prototype.$break;
	    });
	    return result;
	  },

	  collect: function(iterator, context) {
	    iterator = iterator || Prototype.K;
	    var results = [];
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      results.push(iterator.call(context, value, index));
	    });
	    return results;
	  },

	  detect: function(iterator, context) {
	    var result;
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      if (iterator.call(context, value, index)) {
	        result = value;
	        throw Prototype.$break;
	      }
	    });
	    return result;
	  },

	  findAll: function(iterator, context) {
	    var results = [];
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      if (iterator.call(context, value, index))
	        results.push(value);
	    });
	    return results;
	  },

	  grep: function(filter, iterator, context) {
	    iterator = iterator || Prototype.K;
	    var results = [];

	    if (Prototype.O.isString(filter))
	      filter = new RegExp(filter);

	    Prototype.Enumerable.each.call(this,function(value, index) {
	      if (filter.test(value))
	        results.push(iterator.call(context, value, index));
	    });
	    return results;
	  },

	  include: function(object) {
	    if (Prototype.O.isFunction(this.indexOf))
	      if (this.indexOf(object) != -1) return true;

	    var found = false;
	    Prototype.Enumerable.each.call(this,function(value) {
	      if (value == object) {
	        found = true;
	        throw Prototype.$break;
	      }
	    });
	    return found;
	  },

	  inject: function(memo, iterator, context) {
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      memo = iterator.call(context, memo, value, index);
	    });
	    return memo;
	  },

	  invoke: function(method) {
	    var args = Prototype.$A(arguments).slice(1);
	    return Prototype.Enumerable.map.call(this,function(value) {
	      return value[method].apply(value, args);
	    });
	  },

	  max: function(iterator, context) {
	    iterator = iterator || Prototype.K;
	    var result;
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      value = iterator.call(context, value, index);
	      if (result == null || value >= result)
	        result = value;
	    });
	    return result;
	  },

	  min: function(iterator, context) {
	    iterator = iterator || Prototype.K;
	    var result;
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      value = iterator.call(context, value, index);
	      if (result == null || value < result)
	        result = value;
	    });
	    return result;
	  },

	  partition: function(iterator, context) {
	    iterator = iterator || Prototype.K;
	    var trues = [], falses = [];
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      (iterator.call(context, value, index) ?
	        trues : falses).push(value);
	    });
	    return [trues, falses];
	  },

	  pluck: function(property) {
	    var results = [];
	    Prototype.Enumerable.each.call(this,function(value) {
	      results.push(value[property]);
	    });
	    return results;
	  },

	  reject: function(iterator, context) {
	    var results = [];
	    Prototype.Enumerable.each.call(this,function(value, index) {
	      if (!iterator.call(context, value, index))
	        results.push(value);
	    });
	    return results;
	  },

	  sortBy: function(iterator, context) {
	    return Prototype.Enumerable.pluck.call(
	    		Prototype.Enumerable.map.call(this,function(value, index) {
			      return {
			        value: value,
			        criteria: iterator.call(context, value, index)
			      };
			    }).sort(function(left, right) {
			      var a = left.criteria, b = right.criteria;
			      return a < b ? -1 : a > b ? 1 : 0;
			    }),'value');
	  },

	  toArray: function() {
	    return Prototype.Enumerable.map.call(this);
	  },

	  zip: function() {
	    var iterator = Prototype.K, args = Prototype.$A(arguments);
	    if (Prototype.O.isFunction(Prototype.A.last(args)))
	      iterator = args.pop();

	    var collections = Prototype.Enumerable.map.call([this].concat(args),Prototype.$A);
	    return Prototype.Enumerable.map.call(this,function(value, index) {
	      return iterator(Prototype.Enumerable.pluck.call(collections,index));
	    });
	  },

	  size: function() {
	    return Prototype.Enumerable.toArray.call(this).length;
	  },

	  inspect: function() {
	    return '#<Prototype.Enumerable:' + Prototype.Enumerable.inspect.call(Prototype.Enumerable.toArray.call(this)) + '>';
	  }
	},

	N: {
	  toColorPart: function(number) {
	    return Prototype.N.toPaddedString(number, 2, 16);
	  },

	  times: function(number, iterator, context) {
	    Prototype.$R(0, number, true).each(iterator, context);
	    return number;
	  },

	  toPaddedString: function(number, length, radix) {
	    var string = number.toString(radix || 10);
	    return Prototype.S.times('0',length - string.length) + string;
	  },

	},
	
	A: {
		_each: Array.prototype.forEach,
		
	  without: function(array) {
	    var values = Prototype.$A(arguments);
	    values.shift();
	    return array.filter(function(value) {
	      return !Prototype.A.include(values,value);
	    });
	  },
	
	  clear: function(array) {
	    array.length = 0;
	    return array;
	  },
	
	  first: function(array) {
	    return array[0];
	  },
	
	  last: function(array) {
	    return array[array.length - 1];
	  },
	
	  compact: function(array) {
	    return array.filter(function(value) {
	      return value != null;
	    });
	  },
	
	  flatten: function(array) {
	    return array.reduce(function(resArray, value) {
	      return resArray.concat(Prototype.O.isArray(value) ?
	        Prototype.A.flatten(value) : [value]);
	    },[]);
	  },
	
	  reverse: function(array,inline) {
	    return (inline !== false ? array : Prototype.A.toArray(array)).reverse();
	  },
	
	  uniq: function(array,sorted) {
	    return Prototype.A.inject(array,[], function(resArray, value, index) {
	      if (0 == index || (sorted ? Prototype.A.last(resArray) != value : !Prototype.A.include(resArray,value)))
	        resArray.push(value);
	      return array;
	    });
	  },
	
	  intersect: function(array,other) {
	    return Prototype.A.findAll(Prototype.A.uniq(array),function(item) {
	      return Prototype.A.detect(other,function(value) { return item === value });
	    });
	  },
	
	  clone: function(array) {
	    return [].concat(array);
	  },
	
	  size: function(array) {
	    return array.length;
	  },
	
	  inspect: function(array) {
	    return '[' + Prototype.A.map(array,Prototype.O.inspect).join(', ') + ']';
	  },
	},
	
	/* Be careful when using these methods on XUL elements, most of them were
	 * designed to work on HTML elements
	 */

	E: {
	  visible: function(element) {
	    return element.style.display != 'none';
	  },
	
	  toggle: function(element) {
	    Prototype.E[Prototype.E.visible(element) ? 'hide' : 'show'](element);
	    return element;
	  },
	
	  hide: function(element) {
	    element.style.display = 'none';
	    return element;
	  },
	
	  show: function(element) {
	    element.style.display = '';
	    return element;
	  },
	
	  remove: function(element) {
	    element.parentNode.removeChild(element);
	    return element;
	  },
	
	  inspect: function(element) {
	    var result = '<' + element.tagName.toLowerCase();
	    Prototype.$H({'id': 'id', 'className': 'class'}).each(function(pair) {
	      var property = pair[0], attribute = pair[1];
	      var value = (element[property] || '').toString();
	      if (value) result += ' ' + attribute + '=' + Prototype.S.inspect(value,true);
	    });
	    return result + '>';
	  },
	
	  recursivelyCollect: function(element, property) {
	    var elements = [];
	    while (element = element[property])
	      if (element.nodeType == 1)
	        elements.push(element);
	    return elements;
	  },
	
	  ancestors: function(element) {
	    return Prototype.E.recursivelyCollect(element,'parentNode');
	  },
	
	  firstDescendant: function(element) {
	    element = element.firstChild;
	    while (element && element.nodeType != 1) element = element.nextSibling;
	    return element;
	  },
	
	  immediateDescendants: function(element) {
	    if (!(element = element.firstChild)) return [];
	    while (element && element.nodeType != 1) element = element.nextSibling;
	    if (element) return [element].concat(Prototype.E.nextSiblings(elements));
	    return [];
	  },
	
	  previousSiblings: function(element) {
	    return Prototype.E.recursivelyCollect(element,'previousSibling');
	  },
	
	  nextSiblings: function(element) {
	    return Prototype.E.recursivelyCollect(element,'nextSibling');
	  },
	
	  siblings: function(element) {
	    return Prototype.A.reverse(Prototype.E.previousSiblings(element)).concat(Prototype.E.nextSiblings(element));
	  },
	
	  identify: function(element) {
	    var id = Prototype.E.readAttribute(element,'id'), self = arguments.callee;
	    if (id) return id;
	    do { id = 'anonymous_element_' + self.counter++ } while (element.ownerDocument.getElementById(id));
	    Prototype.E.writeAttribute(element,'id', id);
	    return id;
	  },
	
	  readAttribute: function(element, name) {
	    return element.getAttribute(name);
	  },
	
	  writeAttribute: function(element, name, value) {
	    var attributes = { }, t = Prototype.E._attributeTranslations.write;
	
	    if (typeof name == 'object') attributes = name;
	    else attributes[name] = Prototype.O.isUndefined(value) ? true : value;
	
	    for (var attr in attributes) {
	      name = t.names[attr] || attr;
	      value = attributes[attr];
	      if (t.values[attr]) name = t.values[attr](element, value);
	      if (value === false || value === null)
	        element.removeAttribute(name);
	      else if (value === true)
	        element.setAttribute(name, name);
	      else element.setAttribute(name, value);
	    }
	    return element;
	  },
	
	  getHeight: function(element) {
	    return Prototype.E.getDimensions(element).height;
	  },
	
	  getWidth: function(element) {
	    return Prototype.E.getDimensions(element).width;
	  },
	
	  hasClassName: function(element, className) {
	    if (!element) return;
	    var elementClassName = element.className;
	    return (elementClassName.length > 0 && (elementClassName == className ||
	      new RegExp("(^|\\s)" + className + "(\\s|$)").test(elementClassName)));
	  },
	
	  addClassName: function(element, className) {
	    if (!element) return;
	    if (!Prototype.E.hasClassName(element,className))
	      element.className += (element.className ? ' ' : '') + className;
	    return element;
	  },
	
	  removeClassName: function(element, className) {
	    if (!element) return;
	    element.className = Prototype.S.strip(element.className.replace(
	      new RegExp("(^|\\s+)" + className + "(\\s+|$)"), ' '));
	    return element;
	  },
	
	  toggleClassName: function(element, className) {
	    if (!element) return;
	    return Prototype.E[Prototype.E.hasClassName(element,className) ?
	      'removeClassName' : 'addClassName'](element,className);
	  },
	
	  // removes whitespace-only text node children
	  cleanWhitespace: function(element) {
	    var node = element.firstChild;
	    while (node) {
	      var nextNode = node.nextSibling;
	      if (node.nodeType == 3 && !/\S/.test(node.nodeValue))
	        element.removeChild(node);
	      node = nextNode;
	    }
	    return element;
	  },
	
	  descendantOf: function(element, ancestor) {
	    return (element.compareDocumentPosition(ancestor) & 8) === 8;
	  },
	
	  scrollTo: function(win,element) {
	    var pos = Prototype.E.cumulativeOffset(element);
	    win.scrollTo(pos[0], pos[1]);
	    return element;
	  },
	
	  getStyle: function(element, style) {
	    style = style == 'float' ? 'cssFloat' : Prototype.S.camelize(style);
	    var value = element.style[style];
	    if (!value || value == 'auto') {
	      var css = element.ownerDocument.defaultView.getComputedStyle(element, null);
	      value = css ? css[style] : null;
	    }
	    if (style == 'opacity') return value ? parseFloat(value) : 1.0;
	    return value == 'auto' ? null : value;
	  },
	
	  getOpacity: function(element) {
	    return Prototype.E.getStyle(element,'opacity');
	  },
	
	  setStyle: function(element, styles) {
	    var elementStyle = element.style, match;
	    if (Prototype.O.isString(styles)) {
	      element.style.cssText += ';' + styles;
	      return Prototype.S.include(styles,'opacity') ?
	        Prototype.E.setOpacity(element,styles.match(/opacity:\s*(\d?\.?\d*)/)[1]) : element;
	    }
	    for (var property in styles)
	      if (property == 'opacity') Prototype.E.setOpacity(element,styles[property]);
	      else
	        elementStyle[(property == 'float' || property == 'cssFloat') ?
	          (Prototype.O.isUndefined(elementStyle.styleFloat) ? 'cssFloat' : 'styleFloat') :
	            property] = styles[property];
	
	    return element;
	  },
	
	  setOpacity: function(element, value) {
	    element.style.opacity = (value == 1 || value === '') ? '' :
	      (value < 0.00001) ? 0 : value;
	    return element;
	  },
	
	  getDimensions: function(element) {
	    var display = Prototype.E.getStyle(element,'display');
	    if (display != 'none' && display != null) // Safari bug
	      return {width: element.offsetWidth, height: element.offsetHeight};
	
	    // All *Width and *Height properties give 0 on elements with display none,
	    // so enable the element temporarily
	    var els = element.style;
	    var originalVisibility = els.visibility;
	    var originalPosition = els.position;
	    var originalDisplay = els.display;
	    els.visibility = 'hidden';
	    els.position = 'absolute';
	    els.display = 'block';
	    var originalWidth = element.clientWidth;
	    var originalHeight = element.clientHeight;
	    els.display = originalDisplay;
	    els.position = originalPosition;
	    els.visibility = originalVisibility;
	    return {width: originalWidth, height: originalHeight};
	  },
	
	  makePositioned: function(element) {
	    var pos = Prototype.E.getStyle(element, 'position');
	    if (pos == 'static' || !pos) {
	      element._madePositioned = true;
	      element.style.position = 'relative';
	    }
	    return element;
	  },
	
	  undoPositioned: function(element) {
	    if (element._madePositioned) {
	      element._madePositioned = undefined;
	      element.style.position =
	        element.style.top =
	        element.style.left =
	        element.style.bottom =
	        element.style.right = '';
	    }
	    return element;
	  },
	
	  makeClipping: function(element) {
	    if (element._overflow) return element;
	    element._overflow = Prototype.E.getStyle(element, 'overflow') || 'auto';
	    if (element._overflow !== 'hidden')
	      element.style.overflow = 'hidden';
	    return element;
	  },
	
	  undoClipping: function(element) {
	    if (!element._overflow) return element;
	    element.style.overflow = element._overflow == 'auto' ? '' : element._overflow;
	    element._overflow = null;
	    return element;
	  },
	
	  cumulativeOffset: function(element) {
	    var valueT = 0, valueL = 0;
	    do {
	      valueT += element.offsetTop  || 0;
	      valueL += element.offsetLeft || 0;
	      element = element.offsetParent;
	    } while (element);
	    return Prototype.E._returnOffset(valueL, valueT);
	  },
	
	  positionedOffset: function(element) {
	    var valueT = 0, valueL = 0;
	    do {
	      valueT += element.offsetTop  || 0;
	      valueL += element.offsetLeft || 0;
	      element = element.offsetParent;
	      if (element) {
	        if (element.tagName.toUpperCase() == 'BODY') break;
	        var p = Prototype.E.getStyle(element, 'position');
	        if (p !== 'static') break;
	      }
	    } while (element);
	    return Prototype.E._returnOffset(valueL, valueT);
	  },
	
	  absolutize: function(element) {
	    if (Prototype.E.getStyle(element,'position') == 'absolute') return element;
	    // Position.prepare(); // To be done manually by Scripty when it needs it.
	
	    var offsets = Prototype.E.positionedOffset(element);
	    var top     = offsets[1];
	    var left    = offsets[0];
	    var width   = element.clientWidth;
	    var height  = element.clientHeight;
	
	    element._originalLeft   = left - parseFloat(element.style.left  || 0);
	    element._originalTop    = top  - parseFloat(element.style.top || 0);
	    element._originalWidth  = element.style.width;
	    element._originalHeight = element.style.height;
	
	    element.style.position = 'absolute';
	    element.style.top    = top + 'px';
	    element.style.left   = left + 'px';
	    element.style.width  = width + 'px';
	    element.style.height = height + 'px';
	    return element;
	  },
	
	  relativize: function(element) {
	    if (Prototype.E.getStyle(element,'position') == 'relative') return element;
	    // Position.prepare(); // To be done manually by Scripty when it needs it.
	
	    element.style.position = 'relative';
	    var top  = parseFloat(element.style.top  || 0) - (element._originalTop || 0);
	    var left = parseFloat(element.style.left || 0) - (element._originalLeft || 0);
	
	    element.style.top    = top + 'px';
	    element.style.left   = left + 'px';
	    element.style.height = element._originalHeight;
	    element.style.width  = element._originalWidth;
	    return element;
	  },
	
	  cumulativeScrollOffset: function(element) {
	    var valueT = 0, valueL = 0;
	    do {
	      valueT += element.scrollTop  || 0;
	      valueL += element.scrollLeft || 0;
	      element = element.parentNode;
	    } while (element);
	    return Prototype.E._returnOffset(valueL, valueT);
	  },
	
	  getOffsetParent: function(element) {
	    if (element.offsetParent) return element.offsetParent;
	    if (element == element.ownerDocument.body) return element;
	
	    while ((element = element.parentNode) && element != element.ownerDocument.body)
	      if (Prototype.E.getStyle(element, 'position') != 'static')
	        return element;
	
	    return element.ownerDocument.body;
	  },
	
	  viewportOffset: function(forElement) {
	    var valueT = 0, valueL = 0;
	
	    var element = forElement;
	    do {
	      valueT += element.offsetTop  || 0;
	      valueL += element.offsetLeft || 0;
	
	      // Safari fix
	      if (element.offsetParent == element.ownerDocument.body &&
	        Prototype.E.getStyle(element, 'position') == 'absolute') break;
	
	    } while (element = element.offsetParent);
	
	    element = forElement;
	    do {
	      if (element.tagName && (element.tagName.toUpperCase() == 'BODY')) {
	        valueT -= element.scrollTop  || 0;
	        valueL -= element.scrollLeft || 0;
	      }
	    } while (element = element.parentNode);
	
	    return Prototype.E._returnOffset(valueL, valueT);
	  },
	
	  clonePosition: function(element, source) {
	    var options = Prototype.O.extend({
	      setLeft:    true,
	      setTop:     true,
	      setWidth:   true,
	      setHeight:  true,
	      offsetTop:  0,
	      offsetLeft: 0
	    }, arguments[2] || { });
	
	    // find page position of source
	    var p = Prototype.E.viewportOffset(source);
	
	    // find coordinate system to use
	    var delta = [0, 0];
	    var parent = null;
	    // delta [0,0] will do fine with position: fixed elements,
	    // position:absolute needs offsetParent deltas
	    if (Prototype.E.getStyle(element, 'position') == 'absolute') {
	      parent = Prototype.E.getOffsetParent(element);
	      delta = Prototype.E.viewportOffset(parent);
	    }
	
	    // correct by body offsets (fixes Safari)
	    if (parent == element.ownerDocument.body) {
	      delta[0] -= element.ownerDocument.body.offsetLeft;
	      delta[1] -= element.ownerDocument.body.offsetTop;
	    }
	
	    // set position
	    if (options.setLeft)   element.style.left  = (p[0] - delta[0] + options.offsetLeft) + 'px';
	    if (options.setTop)    element.style.top   = (p[1] - delta[1] + options.offsetTop) + 'px';
	    if (options.setWidth)  element.style.width = source.offsetWidth + 'px';
	    if (options.setHeight) element.style.height = source.offsetHeight + 'px';
	    return element;
	  },
	
	  _attributeTranslations: {
		  write: {
		    names: {
		      className: 'class',
		      htmlFor:   'for'
		    },
		    values: { }
		  }
		},
	
		_returnOffset: function(l, t) {
	    var result = [l, t];
	    result.left = l;
	    result.top = t;
	    return result;
	  },
	},

	V: {
	  getDimensions: function(doc) {
	    var dimensions = {
	    		"width" : doc.documentElement['clientWidth'],
	    		"height" : doc.documentElement['clientHeight']
	    };
	    return dimensions;
	  },

	  getWidth: function(doc) {
	    return this.getDimensions(doc).width;
	  },

	  getHeight: function(doc) {
	    return this.getDimensions(doc).height;
	  },

	  getScrollOffsets: function(win,doc) {
	    return Prototype.E._returnOffset(
	      win.pageXOffset || doc.documentElement.scrollLeft || doc.body.scrollLeft,
	      win.pageYOffset || doc.documentElement.scrollTop || doc.body.scrollTop);
	  }
	},
};

Prototype.O.extend(Prototype.Enumerable, {
  map:     Prototype.Enumerable.collect,
  find:    Prototype.Enumerable.detect,
  select:  Prototype.Enumerable.findAll,
  filter:  Prototype.Enumerable.findAll,
  member:  Prototype.Enumerable.include,
  entries: Prototype.Enumerable.toArray,
  every:   Prototype.Enumerable.all,
  some:    Prototype.Enumerable.any
});

/*--------------------------------------------------------------------------*/

Prototype.PeriodicalExecuter = Prototype.Class.create({
  initialize: function(callback, frequency) {
    this.callback = callback;
    this.frequency = frequency;
    this.currentlyExecuting = false;

    this.registerCallback();
  },

  registerCallback: function() {
    this.timer = window.setInterval(Prototype.F.bind(this.onTimerEvent,this), this.frequency * 1000);
  },

  execute: function() {
    this.callback(this);
  },

  stop: function() {
    if (!this.timer) return;
    window.clearInterval(this.timer);
    this.timer = null;
  },

  onTimerEvent: function() {
    if (!this.currentlyExecuting) {
      try {
        this.currentlyExecuting = true;
        this.execute();
      } finally {
        this.currentlyExecuting = false;
      }
    }
  }
});

/*--------------------------------------------------------------------------*/
/* Templates */

Prototype.Template = Prototype.Class.create({
  initialize: function(template, pattern) {
    this.template = template.toString();
    this.pattern = pattern || Prototype.Template.Pattern;
  },

  evaluate: function(object) {
    if (Prototype.O.isFunction(object.toTemplateReplacements))
      object = object.toTemplateReplacements();

    return Prototype.S.gsub(this.template,this.pattern, function(match) {
      if (object == null) return '';

      var before = match[1] || '';
      if (before == '\\') return match[2];

      var ctx = object, expr = match[3];
      var pattern = /^([^.[]+|\[((?:.*?[^\\])?)\])(\.|\[|$)/;
      match = pattern.exec(expr);
      if (match == null) return before;

      while (match != null) {
        var comp = Prototype.S.startsWith(match[1],'[') ? Prototype.S.gsub(match[2],'\\\\]', ']') : match[1];
        ctx = ctx[comp];
        if (null == ctx || '' == match[3]) break;
        expr = expr.substring('[' == match[3] ? match[1].length : match[0].length);
        match = pattern.exec(expr);
      }

      return before + Prototype.S.interpret(ctx);
    });
  }
});
Prototype.Template.Pattern = /(^|.|\r|\n)(#\{(.*?)\})/;

/*--------------------------------------------------------------------------*/
/* Add enumerable methods to Prototype.A */

(function() {
	for (var p in Prototype.Enumerable) {
		Prototype.A[p] = Prototype.F.demethodize(Prototype.Enumerable[p]);
	}
})();

Prototype.A.toArray = Prototype.A.clone;

/*--------------------------------------------------------------------------*/
/* Hash class */

Prototype.Hash = Prototype.Class.create(Prototype.Enumerable, (function() {

  function toQueryPair(key, value) {
    if (Prototype.O.isUndefined(value)) return key;
    return key + '=' + encodeURIComponent(Prototype.S.interpret(value));
  }

  return {
    initialize: function(object) {
      this._object = Prototype.O.isHash(object) ? object.toObject() : Prototype.O.clone(object);
    },

    _each: function(iterator) {
      for (var key in this._object) {
        var value = this._object[key], pair = [key, value];
        pair.key = key;
        pair.value = value;
        iterator(pair);
      }
    },

    set: function(key, value) {
      return this._object[key] = value;
    },

    get: function(key) {
      // simulating poorly supported hasOwnProperty
      if (this._object[key] !== Prototype.O.prototype[key])
        return this._object[key];
    },

    unset: function(key) {
      var value = this._object[key];
      delete this._object[key];
      return value;
    },

    toObject: function() {
      return Prototype.O.clone(this._object);
    },

    keys: function() {
      return this.pluck('key');
    },

    values: function() {
      return this.pluck('value');
    },

    index: function(value) {
      var match = this.detect(function(pair) {
        return pair.value === value;
      });
      return match && match.key;
    },

    merge: function(object) {
      return this.clone().update(object);
    },

    update: function(object) {
      return new Prototype.Hash(object).inject(this, function(result, pair) {
        result.set(pair.key, pair.value);
        return result;
      });
    },

    toQueryString: function() {
      return this.inject([], function(results, pair) {
        var key = encodeURIComponent(pair.key), values = pair.value;

        if (values && typeof values == 'object') {
          if (Prototype.O.isArray(values))
            return results.concat(values.map(Prototype.F.curry(toQueryPair,key)));
        } else results.push(toQueryPair(key, values));
        return results;
      }).join('&');
    },

    inspect: function() {
      return '#<Prototype.Hash:{' + this.map(function(pair) {
        return pair.map(Prototype.O.inspect).join(': ');
      }).join(', ') + '}>';
    },

    toJSON: function() {
      return Prototype.O.toJSON(this.toObject());
    },

    clone: function() {
      return new Prototype.Hash(this);
    }
  }
})());

Prototype.Hash.prototype.toTemplateReplacements = Prototype.Hash.prototype.toObject;
Prototype.Hash.from = Prototype.$H;

/*--------------------------------------------------------------------------*/
/* Number range */

Prototype.NumberRange = Prototype.Class.create(Prototype.Enumerable, {
  initialize: function(start, end, exclusive) {
    this.start = start;
    this.end = end;
    this.exclusive = exclusive;
  },

  _each: function(iterator) {
    var value = this.start;
    while (this.include(value)) {
      iterator(value);
      value = value + 1;
    }
  },

  include: function(value) {
    if (value < this.start)
      return false;
    if (this.exclusive)
      return value < this.end;
    return value <= this.end;
  }
});

/*--------------------------------------------------------------------------*/
/* Ajax implementation */

Prototype.Ajax = {
  getTransport: function() {
    return Components.classes["@mozilla.org/xmlextras/xmlhttprequest;1"].createInstance();
  },

  activeRequestCount: 0,
};

Prototype.Ajax.Responders = {
  responders: [],

  _each: function(iterator) {
    Prototype.A._each.call(this.responders,iterator);
  },

  register: function(responder) {
    if (!this.include(responder))
      this.responders.push(responder);
  },

  unregister: function(responder) {
    this.responders = Prototype.A.without(this.responders,responder);
  },

  dispatch: function(callback, request, transport, json) {
    this.each(function(responder) {
      if (Prototype.O.isFunction(responder[callback])) {
        try {
          responder[callback].apply(responder, [request, transport, json]);
        } catch (e) { }
      }
    });
  }
};

Prototype.O.extend(Prototype.Ajax.Responders, Prototype.Enumerable);

Prototype.Ajax.Responders.register({
  onCreate:   function() { Prototype.Ajax.activeRequestCount++ },
  onComplete: function() { Prototype.Ajax.activeRequestCount-- }
});

Prototype.Ajax.Base = Prototype.Class.create({
  initialize: function(options) {
    this.options = {
      method:       'post',
      asynchronous: true,
      contentType:  'application/x-www-form-urlencoded',
      encoding:     'UTF-8',
      parameters:   '',
      decodeJSON:     true,
    };
    Prototype.O.extend(this.options, options || { });

    this.options.method = this.options.method.toLowerCase();

    if (Prototype.O.isString(this.options.parameters))
      this.options.parameters = Prototype.S.toQueryParams(this.options.parameters);
    else if (Prototype.O.isHash(this.options.parameters))
      this.options.parameters = this.options.parameters.toObject();
  }
});

Prototype.Ajax.Request = Prototype.Class.create(Prototype.Ajax.Base, {
  _complete: false,

  initialize: function($super, url, options) {
    $super(options);
    this.transport = Prototype.Ajax.getTransport();
    this.request(url);
  },

  request: function(url) {
    this.url = url;
    this.method = this.options.method;
    var params = Prototype.O.clone(this.options.parameters);

    if (!Prototype.A.include(['get', 'post'],this.method)) {
      // simulate other verbs over post
      params['_method'] = this.method;
      this.method = 'post';
    }

    this.parameters = params;

    if (params = Prototype.O.toQueryString(params)) {
      // when GET, append parameters to URL
      if (this.method == 'get')
        this.url += (Prototype.S.include(this.url,'?') ? '&' : '?') + params;
      else if (/Konqueror|Safari|KHTML/.test(window.navigator.userAgent))
        params += '&_=';
    }

    try {
      var response = new Prototype.Ajax.Response(this);
      if (this.options.onCreate) this.options.onCreate(response);
      Prototype.Ajax.Responders.dispatch('onCreate', this, response);

      this.transport.open(this.method.toUpperCase(), this.url,
        this.options.asynchronous);

      if (this.options.asynchronous) Prototype.F.defer(Prototype.F.bind(this.respondToReadyState,this),1);

      this.transport.onreadystatechange = Prototype.F.bind(this.onStateChange,this);
      this.setRequestHeaders();

      this.body = this.method == 'post' ? (this.options.postBody || params) : null;
      this.transport.send(this.body);

      /* Force Firefox to handle ready state 4 for synchronous requests */
      if (!this.options.asynchronous && this.transport.overrideMimeType)
        this.onStateChange();

    }
    catch (e) {
      this.dispatchException(e);
    }
  },

  onStateChange: function() {
    var readyState = this.transport.readyState;
    if (readyState > 1 && !((readyState == 4) && this._complete))
      this.respondToReadyState(this.transport.readyState);
  },

  setRequestHeaders: function() {
    var headers = {
      'X-Requested-With': 'XMLHttpRequest',
      'X-Prototype-Version': Prototype.Version,
      'Accept': 'text/javascript, text/html, application/xml, text/xml, */*'
    };

    if (this.method == 'post') {
      headers['Content-type'] = this.options.contentType +
        (this.options.encoding ? '; charset=' + this.options.encoding : '');

      /* Force "Connection: close" for older Mozilla browsers to work
       * around a bug where XMLHttpRequest sends an incorrect
       * Content-length header. See Mozilla Bugzilla #246651.
       */
      if (this.transport.overrideMimeType &&
          (window.navigator.userAgent.match(/Gecko\/(\d{4})/) || [0,2005])[1] < 2005)
            headers['Connection'] = 'close';
    }

    // user-defined headers
    if (typeof this.options.requestHeaders == 'object') {
      var extras = this.options.requestHeaders;

      if (Prototype.O.isFunction(extras.push))
        for (var i = 0, length = extras.length; i < length; i += 2)
          headers[extras[i]] = extras[i+1];
      else
        Prototype.$H(extras).each(function(pair) { headers[pair.key] = pair.value });
    }

    for (var name in headers)
      this.transport.setRequestHeader(name, headers[name]);
  },

  success: function() {
    var status = this.getStatus();
    return !status || (status >= 200 && status < 300);
  },

  getStatus: function() {
    try {
      return this.transport.status || 0;
    } catch (e) { return 0 }
  },

  respondToReadyState: function(readyState) {
    var state = Prototype.Ajax.Request.Events[readyState], response = new Prototype.Ajax.Response(this);

    if (state == 'Complete') {
      try {
        this._complete = true;
        (this.options['on' + response.status]
         || this.options['on' + (this.success() ? 'Success' : 'Failure')]
         || Prototype.emptyFunction)(response, response.headerJSON);
      } catch (e) {
        this.dispatchException(e);
      }

      var contentType = response.getHeader('Content-type');
    }

    try {
      (this.options['on' + state] || Prototype.emptyFunction)(response, response.headerJSON);
      Prototype.Ajax.Responders.dispatch('on' + state, this, response, response.headerJSON);
    } catch (e) {
      this.dispatchException(e);
    }

    if (state == 'Complete') {
      // avoid memory leak in MSIE: clean up
      this.transport.onreadystatechange = Prototype.emptyFunction;
    }
  },

  getHeader: function(name) {
    try {
      return this.transport.getResponseHeader(name) || null;
    } catch (e) { return null }
  },

  dispatchException: function(exception) {
    (this.options.onException || Prototype.emptyFunction)(this, exception);
    Prototype.Ajax.Responders.dispatch('onException', this, exception);
  }
});

Prototype.Ajax.Request.Events =
  ['Uninitialized', 'Loading', 'Loaded', 'Interactive', 'Complete'];

Prototype.Ajax.Response = Prototype.Class.create({
  initialize: function(request){
    this.request = request;
    var transport  = this.transport  = request.transport,
        readyState = this.readyState = transport.readyState;

    if(readyState > 2 || readyState == 4) {
      this.status       = this.getStatus();
      this.statusText   = this.getStatusText();
      this.responseText = Prototype.S.interpret(transport.responseText);
      this.headerJSON   = this._getHeaderJSON();
    }

    if(readyState == 4) {
      var xml = transport.responseXML;
      this.responseXML  = Prototype.O.isUndefined(xml) ? null : xml;
      this.responseJSON = this._getResponseJSON();
    }
  },

  status:      0,
  statusText: '',

  getStatus: Prototype.Ajax.Request.prototype.getStatus,

  getStatusText: function() {
    try {
      return this.transport.statusText || '';
    } catch (e) { return '' }
  },

  getHeader: Prototype.Ajax.Request.prototype.getHeader,

  getAllHeaders: function() {
    try {
      return this.getAllResponseHeaders();
    } catch (e) { return null }
  },

  getResponseHeader: function(name) {
    return this.transport.getResponseHeader(name);
  },

  getAllResponseHeaders: function() {
    return this.transport.getAllResponseHeaders();
  },

  _getHeaderJSON: function() {
    var json = this.getHeader('X-JSON');
    if (!json) return null;
    json = decodeURIComponent(escape(json));
    try {
      return Prototype.S.decodeJSON(json);
    } catch (e) {
      this.request.dispatchException(e);
    }
  },

  _getResponseJSON: function() {
    var options = this.request.options;
    if (!options.decodeJSON || (options.decodeJSON != 'force' &&
      !Prototype.S.include(this.getHeader('Content-type') || '','application/json')) ||
        Prototype.S.blank(this.responseText))
          return null;
    try {
      return Prototype.S.decodeJSON(this.responseText);
    } catch (e) {
      this.request.dispatchException(e);
    }
  }
});

//------------------------------------------------------------

Prototype.E.identify.counter = 1;

Prototype.O.extend(Prototype.E, {
  childElements: Prototype.E.immediateDescendants
});

if (/rv:1\.8\.0/.test(window.navigator.userAgent)) {
  Prototype.E.setOpacity = function(element, value) {
    element.style.opacity = (value == 1) ? 0.999999 :
      (value === '') ? '' : (value < 0.00001) ? 0 : value;
    return element;
  };
}

